==> zio-aws-inspector2_2.13-6.20.83.2-sources.jar: zio/aws/inspector2/model/ResourceScanType.scala <==
package zio.aws.inspector2.model
import scala.jdk.CollectionConverters._
sealed trait ResourceScanType {
  def unwrap: software.amazon.awssdk.services.inspector2.model.ResourceScanType
}
object ResourceScanType {
  def wrap(
      value: software.amazon.awssdk.services.inspector2.model.ResourceScanType
  ): zio.aws.inspector2.model.ResourceScanType = value match {
    case software.amazon.awssdk.services.inspector2.model.ResourceScanType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.inspector2.model.ResourceScanType.EC2 =>
      val r = EC2
      r
    case software.amazon.awssdk.services.inspector2.model.ResourceScanType.ECR =>
      val r = ECR
      r
    case software.amazon.awssdk.services.inspector2.model.ResourceScanType.LAMBDA =>
      val r = LAMBDA
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.inspector2.model.ResourceScanType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.ResourceScanType =
      software.amazon.awssdk.services.inspector2.model.ResourceScanType.UNKNOWN_TO_SDK_VERSION
  }
  case object EC2 extends zio.aws.inspector2.model.ResourceScanType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.ResourceScanType =
      software.amazon.awssdk.services.inspector2.model.ResourceScanType.EC2
  }
  case object ECR extends zio.aws.inspector2.model.ResourceScanType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.ResourceScanType =
      software.amazon.awssdk.services.inspector2.model.ResourceScanType.ECR
  }
  case object LAMBDA extends zio.aws.inspector2.model.ResourceScanType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.ResourceScanType =
      software.amazon.awssdk.services.inspector2.model.ResourceScanType.LAMBDA
  }
}

==> zio-aws-inspector2_3-5.17.201.1-sources.jar: zio/aws/inspector2/model/ResourceScanType.scala <==
package zio.aws.inspector2.model
import scala.jdk.CollectionConverters.*
sealed trait ResourceScanType {
  def unwrap: software.amazon.awssdk.services.inspector2.model.ResourceScanType
}
object ResourceScanType {
  def wrap(
      value: software.amazon.awssdk.services.inspector2.model.ResourceScanType
  ): zio.aws.inspector2.model.ResourceScanType = value match {
    case software.amazon.awssdk.services.inspector2.model.ResourceScanType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.inspector2.model.ResourceScanType.EC2 =>
      val r = EC2
      r
    case software.amazon.awssdk.services.inspector2.model.ResourceScanType.ECR =>
      val r = ECR
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.inspector2.model.ResourceScanType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.ResourceScanType =
      software.amazon.awssdk.services.inspector2.model.ResourceScanType.UNKNOWN_TO_SDK_VERSION
  }
  case object EC2 extends zio.aws.inspector2.model.ResourceScanType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.ResourceScanType =
      software.amazon.awssdk.services.inspector2.model.ResourceScanType.EC2
  }
  case object ECR extends zio.aws.inspector2.model.ResourceScanType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.ResourceScanType =
      software.amazon.awssdk.services.inspector2.model.ResourceScanType.ECR
  }
}
